'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _looksLike = require('./looks-like');

var _looksLike2 = _interopRequireDefault(_looksLike);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// import printAST from 'ast-pretty-print'
function handleGlamorousReferences(references, file, babel) {
  var t = babel.types,
      template = babel.template;

  var buildBuiltInWithConfig = template(`
    GLAMOROUS.BUILT_IN.withConfig({displayName: DISPLAY_NAME})
  `);
  var buildCustomWithConfig = template(`
    GLAMOROUS(ARGUMENTS).withConfig({displayName: DISPLAY_NAME})
  `);

  references.forEach(function (reference) {
    var displayName = getDisplayName(reference);

    handleBuiltIns(reference, displayName);
    handleCustomComponent(reference, displayName);
  });

  function handleBuiltIns(path, displayName) {
    var isBuiltIn = (0, _looksLike2.default)(path, {
      parentPath: {
        type: 'MemberExpression',
        node: {
          property: {
            type: 'Identifier'
          }
        },
        parent: {
          type: 'CallExpression'
        }
      }
    });
    if (!isBuiltIn) {
      return;
    }
    path.parentPath.replaceWith(buildBuiltInWithConfig({
      GLAMOROUS: path.node,
      BUILT_IN: path.parent.property,
      DISPLAY_NAME: t.stringLiteral(displayName)
    }));
  }

  function handleCustomComponent(path, displayName) {
    var isCustom = (0, _looksLike2.default)(path, {
      parent: {
        type: 'CallExpression'
      }
    });
    if (!isCustom) {
      return;
    }
    path.parentPath.replaceWith(buildCustomWithConfig({
      GLAMOROUS: path.node,
      ARGUMENTS: path.parent.arguments,
      DISPLAY_NAME: t.stringLiteral(displayName)
    }));
  }

  // credit: https://github.com/styled-components/babel-plugin-styled-components/blob/37a13e9c21c52148ce6e403100df54c0b1561a88/src/visitors/displayNameAndId.js
  function getDisplayName(path) {
    var componentName = getName(path);
    var filename = getFileName(file);
    if (filename) {
      if (filename === componentName) {
        return componentName;
      }
      return componentName ? `${filename}__${componentName}` : filename;
    } else {
      return componentName;
    }
  }

  // credit: https://github.com/styled-components/babel-plugin-styled-components/blob/37a13e9c21c52148ce6e403100df54c0b1561a88/src/utils/getName.js
  function getName(path) {
    var namedNode = void 0;

    path.find(function (parentPath) {
      if (parentPath.isObjectProperty()) {
        // const X = { Y: glamorous }
        namedNode = parentPath.node.key;
      } else if (parentPath.isVariableDeclarator()) {
        // let X; X = glamorous
        namedNode = parentPath.node.id;
      } else if (parentPath.isStatement()) {
        // we've hit a statement, we should stop crawling up
        return true;
      }

      // we've got an displayName (if we need it) no need to continue
      if (namedNode) {
        return true;
      }
      return false;
    });

    // identifiers are the only thing we can reliably get a name from
    return t.isIdentifier(namedNode) ? namedNode.name : undefined;
  }
}

function getFileName(file) {
  if (!file || file.opts.filename === 'unknown') {
    return '';
  }
  return file.opts.basename === 'index' ? _path2.default.basename(_path2.default.dirname(file.opts.filename)) : file.opts.basename;
}

exports.default = handleGlamorousReferences;