'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (babel) {
  var t = babel.types;

  var references = new Set();
  return {
    name: 'babel-plugin-glamorous-displayName',
    visitor: {
      ImportDeclaration(path) {
        var defaultSpecifierPath = path.get('specifiers')[0];
        if (path.node.source.value !== 'glamorous' || !t.isImportDefaultSpecifier(defaultSpecifierPath)) {
          return;
        }
        var name = defaultSpecifierPath.node.local.name;

        var _path$scope$getBindin = path.scope.getBinding(name),
            referencePaths = _path$scope$getBindin.referencePaths;

        referencePaths.forEach(function (reference) {
          references.add(reference);
        });
      },
      VariableDeclarator(path) {
        var node = path.node;

        if (!isRequireCall(node.init) || !t.isIdentifier(node.id)) {
          return;
        }
        var name = node.id.name;

        var binding = path.scope.getBinding(name);
        // I'm not sure whether this could ever happen
        // but I don't want a bug report hitting me because it did...
        // istanbul ignore else
        if (binding) {
          var referencePaths = binding.referencePaths;

          referencePaths.forEach(function (reference) {
            references.add(reference);
          });
        }
      },
      Program: {
        exit(path, _ref) {
          var file = _ref.file;

          (0, _handleGlamorousReferences2.default)(Array.from(references), file, babel);
        }
      }
    }
  };
};

var _handleGlamorousReferences = require('./handle-glamorous-references');

var _handleGlamorousReferences2 = _interopRequireDefault(_handleGlamorousReferences);

var _looksLike = require('./looks-like');

var _looksLike2 = _interopRequireDefault(_looksLike);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function isRequireCall(callExpression) {
  return (0, _looksLike2.default)(callExpression, {
    type: 'CallExpression',
    callee: {
      name: 'require'
    },
    arguments: function _arguments(args) {
      return args && args.length === 1 && args[0].value === 'glamorous';
    }
  });
}